@@ -78,7 +78,7 @@ sub read_defs($$$)
   $DocsParser::CurrentFile = "$path/$filename";
   if ( ! -r $DocsParser::CurrentFile)
   {
-     print "DocsParser.pm: Warning: Can't read file \"" . $DocsParser::CurrentFile . "\".\n";
+     print STDERR "DocsParser.pm: Warning: Can't read file \"" . $DocsParser::CurrentFile . "\".\n";
      return;
   }
   # Parse
@@ -86,23 +86,22 @@ sub read_defs($$$)
   if( $@ )
   {
     $@ =~ s/at \/.*?$//s;
-    print "\nError in \"" . $DocsParser::CurrentFile . "\":$@\n";
+    print STDERR "\nError in \"" . $DocsParser::CurrentFile . "\":$@\n";
     return;
   }
 
   # C++ overide documentation:
-  $DocsParser::CurrentFile = "$path/$filename_override";
-  if ( ! -r $DocsParser::CurrentFile)
-  {
-     print "DocsParser.pm: Warning: Can't read file \"" . $DocsParser::CurrentFile . "\".\n";
-     return;
-  }
+  $DocsParser::CurrentFile = $path . '/' . $filename_override;
+
+  # It is not an error if the documentation override file does not exist.
+  return unless (-r $DocsParser::CurrentFile);
+
   # Parse
   eval { $objParser->parsefile($DocsParser::CurrentFile) };
   if( $@ )
   {
     $@ =~ s/at \/.*?$//s;
-    print "\nError in \"" . $DocsParser::CurrentFile . "\":$@";
+    print STDERR "\nError in \"" . $DocsParser::CurrentFile . "\":$@";
     return;
   }
 }
@@ -371,17 +370,8 @@ sub convert_tags_to_doxygen($)
     # Remove all para tags (from tmpl sgml files).
     s"&lt;/?para&gt;""g;
 
-    # Use our doxgen since/newin tags:
-    # TODO: Do this generically, regardless of the number:
-    s"Since: 2\.2"\@newin2p2"mg;
-    s"Since: 2\.4"\@newin2p4"mg;
-    s"Since: 2\.6"\@newin2p6"mg;
-    s"Since: 2\.8"\@newin2p8"mg;
-    s"Since: 2\.10"\@newin2p10"mg;
-    s"Since: 2\.12"\@newin2p12"mg;
-    s"Since: 2\.14"\@newin2p14"mg;
-    s"Since: 2\.16"\@newin2p16"mg;
-    s"Since: 2\.18"\@newin2p18"mg;
+    # Use our Doxygen @newin alias:
+    s/\bSince:\s*(\d+)\.(\d+)\b/\@newin{$1,$2}/g;
 
     s"\b-&gt;\b"->"g;
 
@@ -457,7 +447,7 @@ sub substitute_function($$)
 sub non_object_method_name($$)
 {
   my ($doc_func, $name) = @_;
-  if ($$name =~ "^gtk_")
+  if ($$name =~ m/^gtk_/)
   {
     my %gtk_objects = ("gtk_accel_map" => "AccelMap",
                        "gtk_clipboard" => "Clipboard",
@@ -474,7 +464,7 @@ sub non_object_method_name($$)
                        "gtk_recent_filter" => "RecentFilter");
     foreach my $key (keys(%gtk_objects))
     {
-      if ($$name =~ "^$key")
+      if ($$name =~ m/^\Q$key\E/)
       {
         DocsParser::build_method_name($doc_func, "Gtk", $gtk_objects{$key}, $name);
         return;
@@ -512,7 +502,7 @@ sub lookup_object_of_method($$)
   foreach(@parts) { $_ = (length > 2) ? ucfirst : uc; }
 
   # Do a bit of try'n'error.
-  while(scalar(@parts) > 1)
+  while($#parts >= 1)
   {
     my $try = join("", @parts);
 
@@ -535,10 +525,10 @@ sub build_method_name($$$$)
   $prefix =~ s/([a-z])([A-Z])/$1_$2/g;
   $prefix = lc($prefix) . '_';
 
-  if($$name =~ /^$prefix/)
+  if($$name =~ m/^\Q$prefix\E/)
   {
     my $scope = "";
-    $scope = "${module}::${class}::" unless($doc_func =~ /^$prefix/);
+    $scope = "${module}::${class}::" unless($doc_func =~ m/^\Q$prefix\E/);
 
     substr($$name, 0, length($prefix)) = $scope;
   }
